# crm

Crm - JavaScript client for crm
Customer Information Microservice
This SDK is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 0.0.2
- Package version: 0.0.2
- Build package: org.openapitools.codegen.languages.JavascriptClientCodegen

## Installation

### For [Node.js](https://nodejs.org/)

#### npm

To publish the library as a [npm](https://www.npmjs.com/), please follow the procedure in ["Publishing npm packages"](https://docs.npmjs.com/getting-started/publishing-npm-packages).

Then install it via:

```shell
npm install crm --save
```

Finally, you need to build the module:

```shell
npm run build
```

##### Local development

To use the library locally without publishing to a remote npm registry, first install the dependencies by changing into the directory containing `package.json` (and this README). Let's call this `JAVASCRIPT_CLIENT_DIR`. Then run:

```shell
npm install
```

Next, [link](https://docs.npmjs.com/cli/link) it globally in npm with the following, also from `JAVASCRIPT_CLIENT_DIR`:

```shell
npm link
```

To use the link you just defined in your project, switch to the directory you want to use your crm from, and run:

```shell
npm link /path/to/<JAVASCRIPT_CLIENT_DIR>
```

Finally, you need to build the module:

```shell
npm run build
```

#### git

If the library is hosted at a git repository, e.g.https://github.com/GIT_USER_ID/GIT_REPO_ID
then install it via:

```shell
    npm install GIT_USER_ID/GIT_REPO_ID --save
```

### For browser

The library also works in the browser environment via npm and [browserify](http://browserify.org/). After following
the above steps with Node.js and installing browserify with `npm install -g browserify`,
perform the following (assuming *main.js* is your entry file):

```shell
browserify main.js > bundle.js
```

Then include *bundle.js* in the HTML pages.

### Webpack Configuration

Using Webpack you may encounter the following error: "Module not found: Error:
Cannot resolve module", most certainly you should disable AMD loader. Add/merge
the following section to your webpack config:

```javascript
module: {
  rules: [
    {
      parser: {
        amd: false
      }
    }
  ]
}
```

## Getting Started

Please follow the [installation](#installation) instruction and execute the following JS code:

```javascript
var Crm = require('crm');

var defaultClient = Crm.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
var ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = "YOUR API KEY"
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix['X-API-Key'] = "Token"

var api = new Crm.AccountsApi()
var opts = {
  'accountId': "accountId_example" // {String} Taxnexus Record Id of an Account
};
var callback = function(error, data, response) {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
};
api.deleteAccount(opts, callback);

```

## Documentation for API Endpoints

All URIs are relative to *http://crm.vernonkeenan.com:8080/v1*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*Crm.AccountsApi* | [**deleteAccount**](docs/AccountsApi.md#deleteAccount) | **DELETE** /accounts | Delete An Account
*Crm.AccountsApi* | [**getAccounts**](docs/AccountsApi.md#getAccounts) | **GET** /accounts | Get a list of accounts
*Crm.AccountsApi* | [**getAccountsObservable**](docs/AccountsApi.md#getAccountsObservable) | **GET** /accounts/observable | Get Taxnexus Accounts in an observable array
*Crm.AccountsApi* | [**postAccounts**](docs/AccountsApi.md#postAccounts) | **POST** /accounts | Add a new account to Taxnexus
*Crm.AccountsApi* | [**putAccount**](docs/AccountsApi.md#putAccount) | **PUT** /accounts | Update a single account
*Crm.AssetsApi* | [**deleteAsset**](docs/AssetsApi.md#deleteAsset) | **DELETE** /assets | Delete An Asset
*Crm.AssetsApi* | [**getAssets**](docs/AssetsApi.md#getAssets) | **GET** /assets | Get a list of assets
*Crm.AssetsApi* | [**getAssetsObservable**](docs/AssetsApi.md#getAssetsObservable) | **GET** /assets/observable | Get Taxnexus Assets in an observable array
*Crm.AssetsApi* | [**postAssets**](docs/AssetsApi.md#postAssets) | **POST** /assets | Add a new asset to Taxnexus
*Crm.AssetsApi* | [**putAsset**](docs/AssetsApi.md#putAsset) | **PUT** /assets | Update a single asset
*Crm.ContactsApi* | [**deleteContact**](docs/ContactsApi.md#deleteContact) | **DELETE** /contacts | Delete a Contact
*Crm.ContactsApi* | [**getContacts**](docs/ContactsApi.md#getContacts) | **GET** /contacts | Get a list of contacts
*Crm.ContactsApi* | [**getContactsObservable**](docs/ContactsApi.md#getContactsObservable) | **GET** /contacts/observable | Get Taxnexus Contacts in an observable array
*Crm.ContactsApi* | [**postContacts**](docs/ContactsApi.md#postContacts) | **POST** /contacts | Add new contacts
*Crm.ContactsApi* | [**putContacts**](docs/ContactsApi.md#putContacts) | **PUT** /contacts | Update Contact
*Crm.ContractsApi* | [**deleteContract**](docs/ContractsApi.md#deleteContract) | **DELETE** /contracts | Delete An Contract
*Crm.ContractsApi* | [**getContracts**](docs/ContractsApi.md#getContracts) | **GET** /contracts | Get a list of contracts
*Crm.ContractsApi* | [**getContractsObservable**](docs/ContractsApi.md#getContractsObservable) | **GET** /contracts/observable | Get Taxnexus Contracts in an observable array
*Crm.ContractsApi* | [**postContracts**](docs/ContractsApi.md#postContracts) | **POST** /contracts | Add a new contract to Taxnexus
*Crm.ContractsApi* | [**putContract**](docs/ContractsApi.md#putContract) | **PUT** /contracts | Update a single contract
*Crm.CorsApi* | [**accountOptions**](docs/CorsApi.md#accountOptions) | **OPTIONS** /accounts | 
*Crm.CorsApi* | [**accountOptionsObservable**](docs/CorsApi.md#accountOptionsObservable) | **OPTIONS** /accounts/observable | 
*Crm.CorsApi* | [**assetOptions**](docs/CorsApi.md#assetOptions) | **OPTIONS** /assets | 
*Crm.CorsApi* | [**assetOptionsObservable**](docs/CorsApi.md#assetOptionsObservable) | **OPTIONS** /assets/observable | 
*Crm.CorsApi* | [**contactOptions**](docs/CorsApi.md#contactOptions) | **OPTIONS** /contacts | 
*Crm.CorsApi* | [**contactOptionsObservable**](docs/CorsApi.md#contactOptionsObservable) | **OPTIONS** /contacts/observable | 
*Crm.CorsApi* | [**contractOptions**](docs/CorsApi.md#contractOptions) | **OPTIONS** /contracts | 
*Crm.CorsApi* | [**contractOptionsObservable**](docs/CorsApi.md#contractOptionsObservable) | **OPTIONS** /contracts/observable | 
*Crm.CorsApi* | [**leadOptions**](docs/CorsApi.md#leadOptions) | **OPTIONS** /leads | 
*Crm.CorsApi* | [**leadOptionsObservable**](docs/CorsApi.md#leadOptionsObservable) | **OPTIONS** /leads/observable | 
*Crm.LeadsApi* | [**deleteLead**](docs/LeadsApi.md#deleteLead) | **DELETE** /leads | Delete a Contact
*Crm.LeadsApi* | [**getLeads**](docs/LeadsApi.md#getLeads) | **GET** /leads | Get a list of contacts
*Crm.LeadsApi* | [**getLeadsObservable**](docs/LeadsApi.md#getLeadsObservable) | **GET** /leads/observable | Get Taxnexus Leads in an observable array
*Crm.LeadsApi* | [**postLeads**](docs/LeadsApi.md#postLeads) | **POST** /leads | Add new Leads
*Crm.LeadsApi* | [**putLeads**](docs/LeadsApi.md#putLeads) | **PUT** /leads | Update Leads


## Documentation for Models

 - [Crm.Account](docs/Account.md)
 - [Crm.AccountBasic](docs/AccountBasic.md)
 - [Crm.AccountBasicResponse](docs/AccountBasicResponse.md)
 - [Crm.AccountRequest](docs/AccountRequest.md)
 - [Crm.AccountResponse](docs/AccountResponse.md)
 - [Crm.Address](docs/Address.md)
 - [Crm.Asset](docs/Asset.md)
 - [Crm.AssetRequest](docs/AssetRequest.md)
 - [Crm.AssetResponse](docs/AssetResponse.md)
 - [Crm.Contact](docs/Contact.md)
 - [Crm.ContactRequest](docs/ContactRequest.md)
 - [Crm.ContactResponse](docs/ContactResponse.md)
 - [Crm.Contract](docs/Contract.md)
 - [Crm.ContractRequest](docs/ContractRequest.md)
 - [Crm.ContractResponse](docs/ContractResponse.md)
 - [Crm.DeleteResponse](docs/DeleteResponse.md)
 - [Crm.Error](docs/Error.md)
 - [Crm.InvalidError](docs/InvalidError.md)
 - [Crm.InvalidErrorAllOf](docs/InvalidErrorAllOf.md)
 - [Crm.Lead](docs/Lead.md)
 - [Crm.LeadRequest](docs/LeadRequest.md)
 - [Crm.LeadResponse](docs/LeadResponse.md)
 - [Crm.Message](docs/Message.md)
 - [Crm.Pagination](docs/Pagination.md)
 - [Crm.RequestMeta](docs/RequestMeta.md)
 - [Crm.ResponseMeta](docs/ResponseMeta.md)


## Documentation for Authorization



### ApiKeyAuth


- **Type**: API key
- **API key parameter name**: X-API-Key
- **Location**: HTTP header

