# Devops.ClusterApi

All URIs are relative to *http://devops.vernonkeenan.com:8080/v1*

Method | HTTP request | Description
------------- | ------------- | -------------
[**getCluster**](ClusterApi.md#getCluster) | **GET** /clusters/{clusterIdPath} | Get a single Cluster object
[**getClusters**](ClusterApi.md#getClusters) | **GET** /clusters | Get a list Clusters
[**getClustersObservable**](ClusterApi.md#getClustersObservable) | **GET** /clusters/observable | Get Clusters in an observable array
[**postClusters**](ClusterApi.md#postClusters) | **POST** /clusters | Create new Clusters
[**putClusters**](ClusterApi.md#putClusters) | **PUT** /clusters | Update Clustera



## getCluster

> Cluster getCluster(clusterIdPath)

Get a single Cluster object

Return a single Cluster object from datastore as a Singleton

### Example

```javascript
import Devops from 'devops';
let defaultClient = Devops.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
let ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix = 'Token';

let apiInstance = new Devops.ClusterApi();
let clusterIdPath = "clusterIdPath_example"; // String | Taxnexus Record Id of a Cluster
apiInstance.getCluster(clusterIdPath, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clusterIdPath** | **String**| Taxnexus Record Id of a Cluster | 

### Return type

[**Cluster**](Cluster.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## getClusters

> ClusterResponse getClusters(opts)

Get a list Clusters

Return a list of Cluster records from the datastore

### Example

```javascript
import Devops from 'devops';
let defaultClient = Devops.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
let ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix = 'Token';

let apiInstance = new Devops.ClusterApi();
let opts = {
  'clusterId': "clusterId_example", // String | Taxnexus Record Id of a Cluster
  'companyId': "companyId_example", // String | Taxnexus Record Id of a Company
  'limit': 789, // Number | How many objects to return at one time
  'offset': 789 // Number | How many objects to skip? (default 0)
};
apiInstance.getClusters(opts, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clusterId** | **String**| Taxnexus Record Id of a Cluster | [optional] 
 **companyId** | **String**| Taxnexus Record Id of a Company | [optional] 
 **limit** | **Number**| How many objects to return at one time | [optional] 
 **offset** | **Number**| How many objects to skip? (default 0) | [optional] 

### Return type

[**ClusterResponse**](ClusterResponse.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## getClustersObservable

> [Cluster] getClustersObservable()

Get Clusters in an observable array

Returns a Cluster retrieval in a observable array

### Example

```javascript
import Devops from 'devops';
let defaultClient = Devops.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
let ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix = 'Token';

let apiInstance = new Devops.ClusterApi();
apiInstance.getClustersObservable((error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters

This endpoint does not need any parameter.

### Return type

[**[Cluster]**](Cluster.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: Not defined
- **Accept**: application/json


## postClusters

> ClusterResponse postClusters(clusterRequest)

Create new Clusters

Create Clusters in Taxnexus

### Example

```javascript
import Devops from 'devops';
let defaultClient = Devops.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
let ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix = 'Token';

let apiInstance = new Devops.ClusterApi();
let clusterRequest = new Devops.ClusterRequest(); // ClusterRequest | An array of Cluster records
apiInstance.postClusters(clusterRequest, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clusterRequest** | [**ClusterRequest**](ClusterRequest.md)| An array of Cluster records | 

### Return type

[**ClusterResponse**](ClusterResponse.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json


## putClusters

> ClusterResponse putClusters(clusterRequest)

Update Clustera

Update Cluster in Taxnexus

### Example

```javascript
import Devops from 'devops';
let defaultClient = Devops.ApiClient.instance;
// Configure API key authorization: ApiKeyAuth
let ApiKeyAuth = defaultClient.authentications['ApiKeyAuth'];
ApiKeyAuth.apiKey = 'YOUR API KEY';
// Uncomment the following line to set a prefix for the API key, e.g. "Token" (defaults to null)
//ApiKeyAuth.apiKeyPrefix = 'Token';

let apiInstance = new Devops.ClusterApi();
let clusterRequest = new Devops.ClusterRequest(); // ClusterRequest | An array of Cluster records
apiInstance.putClusters(clusterRequest, (error, data, response) => {
  if (error) {
    console.error(error);
  } else {
    console.log('API called successfully. Returned data: ' + data);
  }
});
```

### Parameters


Name | Type | Description  | Notes
------------- | ------------- | ------------- | -------------
 **clusterRequest** | [**ClusterRequest**](ClusterRequest.md)| An array of Cluster records | 

### Return type

[**ClusterResponse**](ClusterResponse.md)

### Authorization

[ApiKeyAuth](../README.md#ApiKeyAuth)

### HTTP request headers

- **Content-Type**: application/json
- **Accept**: application/json

